# Stoffel
Capture Excel or Sheets figures as a jpeg for easy upload to Powerpoint or Slides. 

## Core Features
- [x] - Dial in scopes
- [x] - Simplify Google Oauth
- [x] - Delete Excel files after use
- [x] - Set .ENV vars
- [x] - Connection file structure
- [x] - Server side file structure
- [x] - Resize images w/ PIL before pasting to PPT
- [x] - Error when saving all blanks
- [x] - No duplicate projects
- [x] - Open Source/Destination
- [x] - Delete Project
- [x] - Aesthetics on File Modal
- [x] - Home/Instructions Page
- [ ] - Packaging for easy install

## Future Features
- [ ] - Able to name individual connections
- [ ] - Search for files
- [ ] - Sort and filter options for files
- [ ] - Construct file path with nav in file select
- [ ] - Page number to page id for PPT and Slides
- [ ] - Search bar for projects
- [ ] - Progress bar to show completion when running
- [ ] - Save project automatically when you click "Run" button




